<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bqi">
<context>
    <name>AlbumControl</name>
    <message>
        <location filename="../src/albumControl.cpp" line="257"/>
        <source>All photos and videos</source>
        <translation>poy šîvātā vo filmā</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="285"/>
        <source>Disk is busy, cannot eject now</source>
        <translation>disk enê kār ekone, sako natari dêrāris</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="286"/>
        <source>OK</source>
        <translation>xā</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="903"/>
        <source>Fullscreen</source>
        <translation>poy balga</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="906"/>
        <source>Exit fullscreen/slideshow</source>
        <translation>vêdar zayďên zê poy balga/nêšow dāďênê êslāyd</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="912"/>
        <source>Help</source>
        <translation>hayâri</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="915"/>
        <source>Display shortcuts</source>
        <translation>niyaštgêrê miyowbor</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="918"/>
        <source>Display in file manager</source>
        <translation>niyaštgêr mênê dîvowdâri fāyl</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="921"/>
        <source>Slide show</source>
        <translation>nêšow dāďênê êslāyd</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="924"/>
        <source>View</source>
        <translation>niyaštên</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="927"/>
        <source>Export photos</source>
        <translation>vê dar kerdênê šîvātā</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="930"/>
        <source>Import photos/videos</source>
        <translation>vê mên avordênê šîvātā/filmā</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="933"/>
        <source>Select all</source>
        <translation>pêsandê poy</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="936"/>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="939"/>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="942"/>
        <source>Photo/Video info</source>
        <translation>dovêsmandi šîvāt/film</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="945"/>
        <source>Set as wallpaper</source>
        <translation>sāmov vê onvānê balga zêmîna</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="948"/>
        <source>Rotate clockwise</source>
        <translation>dêr xardên vê jo'meštê šāxakā sāat </translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="951"/>
        <source>Rotate counterclockwise</source>
        <translation>dêr xardên čavāsê jo'mêštê šāxakā sāat</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="957"/>
        <source>Zoom in</source>
        <translation>gap kerdên </translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="960"/>
        <source>Zoom out</source>
        <translation>kučir kerdên</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="963"/>
        <source>Previous</source>
        <translation>niyâyi</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="966"/>
        <source>Next</source>
        <translation>dindâyi</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="969"/>
        <source>Favorite</source>
        <translation>xāsta</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="972"/>
        <source>Unfavorite</source>
        <translation>naxāsta</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="975"/>
        <source>New album</source>
        <translation>ālbom nu</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="978"/>
        <source>Rename album</source>
        <translation>ālêštê nomê ālbom</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="981"/>
        <source>Page up</source>
        <translation>balga royi</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="984"/>
        <source>Page down</source>
        <translation>balgê lami</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1026"/>
        <source>Photos</source>
        <translation>šîvātā</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1029"/>
        <source>Albums</source>
        <translation>ālbomā</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1032"/>
        <source>Settings</source>
        <translation>sāmovā</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1601"/>
        <source>Favorites</source>
        <translation>xāstênýal</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1603"/>
        <source>Screen Capture</source>
        <translation>zaftê niyaštgêr</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1605"/>
        <source>Camera</source>
        <translation>šîvātgêr</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1607"/>
        <source>Draw</source>
        <translation>kašiďên</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1700"/>
        <source>Unnamed</source>
        <translation>bînom</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="2145"/>
        <source>%1Year%2Month%3Day</source>
        <translation>%1سال%2ماه%3روز</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="2199"/>
        <source>Channel</source>
        <translation>torga</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="2400"/>
        <source>Pictures</source>
        <translation>šîvātā</translation>
    </message>
</context>
<context>
    <name>AlbumTitle</name>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="112"/>
        <source>New album</source>
        <translation>ālbom nu</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="119"/>
        <source>Import folders</source>
        <translation>mên avordênê dobalgêyal</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="130"/>
        <source>Album</source>
        <translation>ālbom</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="133"/>
        <source>Album is a stylish management tool for viewing and organizing photos and videos.</source>
        <translation>ālbom ya awzārê dîvowdâri tis si nýaštên vo sāmow dāďên vê šîvātā vo filmā hêď.</translation>
    </message>
    <message>
        <source>%1 is released under %2</source>
        <translation type="vanished">%1 zîrê %2 pêšk êbu</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="177"/>
        <source>Show side pane</source>
        <translation>nêšow dāďênê čārguša kêli</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="177"/>
        <source>Hide side pane</source>
        <translation>bîďār kerdênê čārguša kêli</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="222"/>
        <source>Original ratio</source>
        <translation>nêsbatê asli</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="222"/>
        <source>Square thumbnails</source>
        <translation>nêšow dāďên šîvātā jur čār gušêyalê kučir</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="262"/>
        <source>Y</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="274"/>
        <source>M</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="285"/>
        <source>D</source>
        <translation>r</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="296"/>
        <source>All</source>
        <translation>poy</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="401"/>
        <source>Search</source>
        <translation>pitiniďên</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="483"/>
        <source>Import Photos and Videos</source>
        <translation>vê mên avordênê šîvātā vo filmā</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="514"/>
        <source>Favorite</source>
        <translation>xāsta</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="514"/>
        <source>Unfavorite</source>
        <translation>naxāsta</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="546"/>
        <source>Rotate</source>
        <translation>dêr xardên</translation>
    </message>
    <message>
        <location filename="../qml/AlbumTitle.qml" line="566"/>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
</context>
<context>
    <name>AllCollection</name>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/AllCollection.qml" line="73"/>
        <source>1 photo</source>
        <translation>šîvāt 1</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/AllCollection.qml" line="75"/>
        <source>%1 photos</source>
        <translation>%1 šîvāt</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/AllCollection.qml" line="83"/>
        <source>1 video</source>
        <translation>1 film</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/AllCollection.qml" line="85"/>
        <source>%1 videos</source>
        <translation>%1 film</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/AllCollection.qml" line="192"/>
        <source>No results</source>
        <translation>bî nêtija</translation>
    </message>
</context>
<context>
    <name>CustomAlbum</name>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="87"/>
        <source>1 photo</source>
        <translation>šîvāt 1</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="89"/>
        <source>%1 photos</source>
        <translation>%1 šîvāt</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="97"/>
        <source>1 video</source>
        <translation>1 film</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="99"/>
        <source>%1 videos</source>
        <translation>%1 film</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="152"/>
        <source>0 item</source>
        <translation>0 عنصر</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CustomAlbum/CustomAlbum.qml" line="214"/>
        <source>No results</source>
        <translation>bî nêtija</translation>
    </message>
</context>
<context>
    <name>DBManager</name>
    <message>
        <location filename="../src/dbmanager/dbmanager.cpp" line="465"/>
        <source>Screen Capture</source>
        <translation>zaftê niyaštgêr</translation>
    </message>
    <message>
        <location filename="../src/dbmanager/dbmanager.cpp" line="466"/>
        <source>Camera</source>
        <translation>šîvātgêr</translation>
    </message>
    <message>
        <location filename="../src/dbmanager/dbmanager.cpp" line="467"/>
        <source>Draw</source>
        <translation>kašiďên</translation>
    </message>
    <message>
        <location filename="../src/dbmanager/dbmanager.cpp" line="1991"/>
        <source>(copy)</source>
        <translation>(lefgiri)</translation>
    </message>
</context>
<context>
    <name>DayCollection</name>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/DayCollection.qml" line="116"/>
        <source>Successfully added to “%1”</source>
        <translation>vê xuwi ezaf vâbi vê “%1”</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/DayCollection.qml" line="181"/>
        <source>1 photo</source>
        <translation>šîvāt 1</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/DayCollection.qml" line="183"/>
        <source>%1 photos</source>
        <translation> %1 šîvāt</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/DayCollection.qml" line="191"/>
        <source>1 video</source>
        <translation>1 film</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/DayCollection.qml" line="193"/>
        <source>%1 videos</source>
        <translation>%1 film</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <location filename="../src/albumControl.cpp" line="1091"/>
        <source>%1 Drive</source>
        <translation>%1 dêrāyv</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1095"/>
        <source>Blank %1 Disc</source>
        <translation>%1 disk pati</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1099"/>
        <source>%1 Encrypted</source>
        <translation>%1 razm nāďê vâbiďa</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1102"/>
        <source>%1 Volume</source>
        <translation>%1 hêndā bong</translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="48"/>
        <source>Are you sure you want to delete this file locally?</source>
        <translation>zê rāsti êxoy î fāylê mahalli pāk koni?</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="49"/>
        <source>You can restore it in the trash</source>
        <translation>tari zê mênê dalâšqâli vorganis</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="51"/>
        <source>Are you sure you want to delete %1 files locally?</source>
        <translation>zê rāsti êxoy %1 fāylê mahalli pāk koni?</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="52"/>
        <source>You can restore them in the trash</source>
        <translation>tari zê mênê dalâšqâli vorganisow</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="56"/>
        <source>Are you sure you want to permanently delete this file?</source>
        <translation>zê rāsti êxoy î fāylê si hamîša pāk koni??</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="57"/>
        <source>You cannot restore it any longer</source>
        <translation>di natari vorganis</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="59"/>
        <source>Are you sure you want to permanently delete %1 files?</source>
        <translation>zê rāsti êxoy %1 fāyl si hamîša pāk koni??</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="60"/>
        <source>You cannot restore them any longer</source>
        <translation>di natari vorganisow</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="111"/>
        <source>Cancel</source>
        <translation>raď kerdên</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeleteDialog.qml" line="128"/>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
</context>
<context>
    <name>DeviceAlbum</name>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="66"/>
        <source>1 photo</source>
        <translation>šîvāt 1</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="68"/>
        <source>%1 photos</source>
        <translation>%1 šîvāt</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="75"/>
        <source>1 video</source>
        <translation>1 film</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="77"/>
        <source>%1 videos</source>
        <translation>%1 film</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="168"/>
        <source>Import to:</source>
        <translation>avordên mênê:</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="178"/>
        <source>Import</source>
        <translation>vê mên avordên</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="178"/>
        <source>New Album</source>
        <translation>ālbom nu</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="205"/>
        <source>Import All</source>
        <translation>vê mên avordênê poy</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="206"/>
        <source>Import 1 Item</source>
        <translation>vê mên avordên 1 āytêm</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="207"/>
        <source>Import %1 Items</source>
        <translation>vê mên avordên %1 āytêm</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="214"/>
        <source>Import successful</source>
        <translation>vê xuwi vay mênês</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/DeviceAlbum/DeviceAlbum.qml" line="266"/>
        <source>No results</source>
        <translation>bî nêtija</translation>
    </message>
</context>
<context>
    <name>DeviceLoadDialog</name>
    <message>
        <location filename="../qml/Control/DeviceLoadDialog.qml" line="42"/>
        <source>Loading...</source>
        <translation>enê lo'd ebu...</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeviceLoadDialog.qml" line="51"/>
        <source>Cancel</source>
        <translation>raď kerdên</translation>
    </message>
    <message>
        <location filename="../qml/Control/DeviceLoadDialog.qml" line="59"/>
        <source>Ignore</source>
        <translation>tî bandi</translation>
    </message>
</context>
<context>
    <name>EmptyWarningDialog</name>
    <message>
        <location filename="../qml/Control/EmptyWarningDialog.qml" line="27"/>
        <source>File name cannot be empty!</source>
        <translation>nomê fāyl natarê pati bu!</translation>
    </message>
    <message>
        <location filename="../qml/Control/EmptyWarningDialog.qml" line="36"/>
        <source>OK</source>
        <translation>xā</translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="56"/>
        <source>Export</source>
        <translation>vêdar kerdên</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="73"/>
        <source>Name:</source>
        <translation>nom:</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="105"/>
        <source>Save to:</source>
        <translation>zaft kerdên mên:</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="121"/>
        <source>Pictures</source>
        <translation>šîvātā</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="122"/>
        <source>Documents</source>
        <translation>sanadā</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="123"/>
        <source>Downloads</source>
        <translation>dānlodā</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="124"/>
        <source>Desktop</source>
        <translation>dêsktāp</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="125"/>
        <source>Videos</source>
        <translation>filmā</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="126"/>
        <source>Music</source>
        <translation>ārêńg</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="127"/>
        <source>Select other directories</source>
        <translation>pêsandê dobalgêyalê dýar</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="165"/>
        <source>Format:</source>
        <translation>format:</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="203"/>
        <source>Quality:</source>
        <translation>kêyfiyat:</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="247"/>
        <source>Cancel</source>
        <translation>raď kerdên</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="264"/>
        <source>Confirm</source>
        <translation>qêwul kerdên</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="280"/>
        <source>Export successful</source>
        <translation>vê dar kerdên vê xuwi bî</translation>
    </message>
    <message>
        <location filename="../qml/Control/ExportDialog.qml" line="282"/>
        <source>Export failed</source>
        <translation>vê dar kerdên raď vâbi</translation>
    </message>
</context>
<context>
    <name>FileControl</name>
    <message>
        <location filename="../src/filecontrol.cpp" line="834"/>
        <source>Fullscreen</source>
        <translation>poy balga</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="838"/>
        <source>Exit fullscreen</source>
        <translation>vêdar zayďênê poy balga</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="842"/>
        <source>Extract text</source>
        <translation>dêravordênê hîl</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="846"/>
        <source>Slide show</source>
        <translation>nêšow dāďênê êslāyd</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="850"/>
        <source>Rename</source>
        <translation>ālêštê nom</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="854"/>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="858"/>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="862"/>
        <source>Rotate clockwise</source>
        <translation>dêr xardên vê jo'meštê šāxakā sāat </translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="866"/>
        <source>Rotate counterclockwise</source>
        <translation>dêr xardên čavāsê jo'mêštê šāxakā sāat</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="870"/>
        <source>Set as wallpaper</source>
        <translation>sāmov vê onvānê balga zêmîna</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="874"/>
        <source>Display in file manager</source>
        <translation>niyaštgêr mênê dîvowdâri fāyl</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="878"/>
        <source>Image info</source>
        <translation>dovêsmandi šîvāt</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="882"/>
        <source>Previous</source>
        <translation>niyâyi</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="886"/>
        <source>Next</source>
        <translation>dindâyi</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="890"/>
        <source>Zoom in</source>
        <translation>gap kerdên </translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="894"/>
        <source>Zoom out</source>
        <translation>kučir kerdên</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="898"/>
        <source>Open</source>
        <translation>gušiďên</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="902"/>
        <source>Print</source>
        <translation>čāp</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="926"/>
        <source>Image Viewing</source>
        <translation>niyaštênê šîvāt</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="930"/>
        <source>Help</source>
        <translation>hayâri</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="934"/>
        <source>Display shortcuts</source>
        <translation>niyaštgêrê miyowbor</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="942"/>
        <source>Settings</source>
        <translation>sāmovā</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="950"/>
        <source>Select all</source>
        <translation>pêsandê poy</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="958"/>
        <source>Live Text</source>
        <translation>hîlê zênda</translation>
    </message>
</context>
<context>
    <name>FilterComboBox</name>
    <message>
        <location filename="../qml/Control/FilterComboBox.qml" line="20"/>
        <source>All</source>
        <translation>poy</translation>
    </message>
    <message>
        <location filename="../qml/Control/FilterComboBox.qml" line="21"/>
        <source>Photos</source>
        <translation>šîvātā</translation>
    </message>
    <message>
        <location filename="../qml/Control/FilterComboBox.qml" line="22"/>
        <source>Videos</source>
        <translation>filmā</translation>
    </message>
</context>
<context>
    <name>GlobalStatus</name>
    <message>
        <location filename="../src/globalstatus.cpp" line="807"/>
        <source>1 item selected (1 photo)</source>
        <translation>1 āytêm pêsand vâbi (1 šîvāt)</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="809"/>
        <source>1 item selected (1 video)</source>
        <translation>1 āytêm pêsand vâbi (1 film)</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="811"/>
        <source>%1 items selected (%1 photos)</source>
        <translation>%1 āytêm pêsand vâbi (%1 šîvāt)</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="813"/>
        <source>%1 items selected (%1 videos)</source>
        <translation>%1 āytêm pêsand vâbi (%1 film)</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="815"/>
        <source>%1 item selected (1 photo, 1 video)</source>
        <translation>%1 āytêm pêsand vâbi (1 šîvāt, 1 film)</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="817"/>
        <source>%1 items selected (1 photo, %2 videos)</source>
        <translation>%1 āytêm pêsand vâbi (1 šîvāt, %2 film)</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="819"/>
        <source>%1 items selected (%2 photos, 1 video)</source>
        <translation>%1 āytêm pêsand vâbi (%2 šîvāt, 1 film)</translation>
    </message>
    <message>
        <location filename="../src/globalstatus.cpp" line="821"/>
        <source>%1 items selected (%2 photos, %3 videos)</source>
        <translation>%1 āytêm pêsand vâbi (%2 šîvāt, %3 film)</translation>
    </message>
</context>
<context>
    <name>GlobalVar</name>
    <message>
        <location filename="../qml/GlobalVar.qml" line="30"/>
        <source>The photo/video already exists</source>
        <translation>šîvāt/film zê pîštar hêďês</translation>
    </message>
    <message>
        <location filename="../qml/GlobalVar.qml" line="38"/>
        <source>The file format is not supported</source>
        <translation>formatê fāyl lādêrār navâbiďê</translation>
    </message>
</context>
<context>
    <name>HaveImportedView</name>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/HaveImportedView.qml" line="98"/>
        <source>Successfully added to “%1”</source>
        <translation>vê xuwi ezaf vâbi vê “%1”</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/HaveImportedView.qml" line="153"/>
        <source>1 photo</source>
        <translation>šîvāt 1</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/HaveImportedView.qml" line="155"/>
        <source>%1 photos</source>
        <translation>%1 šîvāt</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/HaveImportedView.qml" line="163"/>
        <source>1 video</source>
        <translation>1 film</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/HaveImportedView.qml" line="165"/>
        <source>%1 videos</source>
        <translation>%1 film</translation>
    </message>
</context>
<context>
    <name>ImportTimeLineView</name>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="195"/>
        <source>Import</source>
        <translation>vê mên avordên</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="320"/>
        <source>1 photo</source>
        <translation>1 šîvāt</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="322"/>
        <source>1 video</source>
        <translation>1 film</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="324"/>
        <source>%n photos</source>
        <translation>%n šîvāt%n šîvāt</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="326"/>
        <source>%n videos</source>
        <translation>%n film%n film</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="328"/>
        <source>%n items</source>
        <translation>%n āytêm%n āytêm</translation>
    </message>
</context>
<context>
    <name>ImportedlListView</name>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/ImportedlListView.qml" line="150"/>
        <source>Imported on</source>
        <translation>vayďê mênê</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/ImportedlListView.qml" line="150"/>
        <source>1 item</source>
        <translation>1 āytêm</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/HaveImportedView/ImportedlListView.qml" line="150"/>
        <source>%1 items</source>
        <translation>%1 āytêm</translation>
    </message>
</context>
<context>
    <name>InfomationDialog</name>
    <message>
        <source>Basic info</source>
        <translation type="vanished">dovêsmandi bončak</translation>
    </message>
    <message>
        <source>File name</source>
        <translation type="vanished">nomê fāyl</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="vanished">hêndā</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation type="vanished">bo'dā</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">'no </translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="vanished">virgārê zaft vâbiďe</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation type="vanished">virgārê ālêšt vâbiďe</translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="vanished">juziyāt</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation type="vanished">fêrāqî</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation type="vanished">barnoma bêrč zayďên</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation type="vanished">diri kânunî</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation type="vanished">iso</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation type="vanished">hālatê bêrč zayďên </translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation type="vanished">zamowê bêrč zayďên</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation type="vanished">bêrč</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation type="vanished">jobrānê bêrč zayďên</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation type="vanished">gaptarin fêrāqî</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation type="vanished">jāga' rańgi</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation type="vanished">hālatê hêndā gêrîďên</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation type="vanished">têrāzê êsbîďi</translation>
    </message>
    <message>
        <source>Device model</source>
        <translation type="vanished">modêlê dasgā</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation type="vanished">modêlê lênz</translation>
    </message>
</context>
<context>
    <name>InformationDialog</name>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="82"/>
        <source>Basic info</source>
        <translation>dovêsmandi bončak</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="95"/>
        <source>File name</source>
        <translation>nomê fāyl</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="106"/>
        <source>Size</source>
        <translation>hêndā</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="113"/>
        <source>Dimensions</source>
        <translation>bo'dā</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="120"/>
        <source>Type</source>
        <translation>'no </translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="132"/>
        <source>Date captured</source>
        <translation>virgārê zaft vâbiďe</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="139"/>
        <source>Date modified</source>
        <translation>virgārê ālêšt vâbiďe</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="149"/>
        <source>Details</source>
        <translation>juziyāt</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="162"/>
        <source>Aperture</source>
        <translation>fêrāqî</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="170"/>
        <source>Exposure program</source>
        <translation>barnoma bêrč zayďên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="177"/>
        <source>Focal length</source>
        <translation>diri kânunî</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="183"/>
        <source>ISO</source>
        <translation>iso</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="190"/>
        <source>Exposure mode</source>
        <translation>hālatê bêrč zayďên </translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="196"/>
        <source>Exposure time</source>
        <translation>zamowê bêrč zayďên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="202"/>
        <source>Flash</source>
        <translation>bêrč</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="209"/>
        <source>Flash compensation</source>
        <translation>jobrānê bêrč zayďên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="215"/>
        <source>Max aperture</source>
        <translation>gaptarin fêrāqî</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="222"/>
        <source>Colorspace</source>
        <translation>jāga' rańgi</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="229"/>
        <source>Metering mode</source>
        <translation>hālatê hêndā gêrîďên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="236"/>
        <source>White balance</source>
        <translation>têrāzê êsbîďi</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="247"/>
        <source>Device model</source>
        <translation>modêlê dasgā</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/InformationDialog/InformationDialog.qml" line="254"/>
        <source>Lens model</source>
        <translation>modêlê lênz</translation>
    </message>
</context>
<context>
    <name>MainAlbumView</name>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="245"/>
        <source>Importing...</source>
        <translation>enê yā mênês...</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="246"/>
        <source>Imported:</source>
        <translation>mênês vayďê:</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="253"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="263"/>
        <source>Import successful</source>
        <translation>vê xuwi vay mênês</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="270"/>
        <source>Import failed</source>
        <translation>vê mên avordên raď vâbi</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="281"/>
        <source>Deleted:</source>
        <translation>تم الحذف:</translation>
    </message>
    <message>
        <location filename="../qml/MainAlbumView.qml" line="283"/>
        <source>Deleting...</source>
        <translation>enê pāk ekonê...</translation>
    </message>
</context>
<context>
    <name>MainStack</name>
    <message>
        <location filename="../qml/PreviewImageViewer/MainStack.qml" line="125"/>
        <source>Select pictures</source>
        <translation>pêsandê šîvātā</translation>
    </message>
</context>
<context>
    <name>MenuItemStates</name>
    <message>
        <location filename="../qml/MenuItemStates.qml" line="104"/>
        <source>Export successful</source>
        <translation>vê dar kerdên vê xuwi bî</translation>
    </message>
    <message>
        <location filename="../qml/MenuItemStates.qml" line="106"/>
        <source>Export failed</source>
        <translation>vê dar kerdên raď vâbi</translation>
    </message>
</context>
<context>
    <name>MonthCollection</name>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/MonthCollection.qml" line="154"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
</context>
<context>
    <name>NewAlbumDialog</name>
    <message>
        <location filename="../qml/Control/NewAlbumDialog.qml" line="25"/>
        <source>Unnamed</source>
        <translation>bînom</translation>
    </message>
    <message>
        <location filename="../qml/Control/NewAlbumDialog.qml" line="56"/>
        <source>New Album</source>
        <translation>ālbom nu</translation>
    </message>
    <message>
        <location filename="../qml/Control/NewAlbumDialog.qml" line="72"/>
        <source>Name:</source>
        <translation>nom:</translation>
    </message>
    <message>
        <location filename="../qml/Control/NewAlbumDialog.qml" line="103"/>
        <source>Cancel</source>
        <translation>raď kerdên</translation>
    </message>
    <message>
        <location filename="../qml/Control/NewAlbumDialog.qml" line="120"/>
        <source>Confirm</source>
        <translation>qêwul kerdên</translation>
    </message>
</context>
<context>
    <name>NoPermissionImageDelegate</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ImageDelegate/NoPermissionImageDelegate.qml" line="22"/>
        <source>You have no permission to view the image</source>
        <translation>navā šîvātê nýa'ri</translation>
    </message>
</context>
<context>
    <name>NoPictureView</name>
    <message>
        <location filename="../qml/ThumbnailImageView/NoPictureView.qml" line="60"/>
        <source>Import Photos and Videos</source>
        <translation>vê mên avordênê šîvātā vo filmā</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/NoPictureView.qml" line="69"/>
        <source>No photos or videos found</source>
        <translation>hîč šîvāt yā filmi najurêhest</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/NoPictureView.qml" line="69"/>
        <source>Or drag them here</source>
        <translation>yā ononê bêkaš ičo</translation>
    </message>
</context>
<context>
    <name>NoResultWidget</name>
    <message>
        <location filename="../src/widgets/widgtes/noresultwidget.cpp" line="39"/>
        <source>No results</source>
        <translation>bî nêtija</translation>
    </message>
</context>
<context>
    <name>NonexistImageDelegate</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ImageDelegate/NonexistImageDelegate.qml" line="42"/>
        <source>Image file not found</source>
        <translation>fāylê šîvâti najurêhest</translation>
    </message>
</context>
<context>
    <name>OpenImageWidget</name>
    <message>
        <location filename="../qml/PreviewImageViewer/OpenImageWidget.qml" line="35"/>
        <source>Open Image</source>
        <translation>فتح الصورة</translation>
    </message>
</context>
<context>
    <name>PathManager</name>
    <message>
        <location filename="../src/albumControl.cpp" line="1073"/>
        <source>System Disk</source>
        <translation>diskê sistêm</translation>
    </message>
</context>
<context>
    <name>PropertyActionItemDelegate</name>
    <message>
        <location filename="../qml/PreviewImageViewer/PropertyActionItemDelegate.qml" line="67"/>
        <source>The file already exists, please use another name</source>
        <translation>fāyl zê pîštar hêďês, ya nomê di vê kār bêgêr</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/albumControl.cpp" line="614"/>
        <source>%1/%2/%3 %4:%5</source>
        <translation>%1/%2/%3 %4:%5</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="645"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="651"/>
        <source>%1/%2</source>
        <translation>%1/%2</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="275"/>
        <source>%1/%2/%3</source>
        <translation>%1/%2/%3</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="343"/>
        <source>All</source>
        <translation>poy</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="359"/>
        <source>Photos</source>
        <translation>šîvātā</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="366"/>
        <source>Videos</source>
        <translation>filmā</translation>
    </message>
    <message>
        <location filename="../src/albumControl.cpp" line="1330"/>
        <source>Trash</source>
        <translation>dalâšqâli</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Album</source>
        <translation>ālbom</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Main</source>
        <comment>Album is a fashion manager for viewing and organizing photos and videos.</comment>
        <translation>الرئيسية</translation>
    </message>
    <message>
        <location filename="../src/unionimage/unionimage_global.h" line="269"/>
        <source>day</source>
        <translation>ruz</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="303"/>
        <source>Imported on</source>
        <translation>vayďê mênê</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="303"/>
        <source> %1-%2-%3 %4</source>
        <translation>%1-%2-%3 %4</translation>
    </message>
    <message>
        <location filename="../src/widgets/importtimelineview/importtimelineview.cpp" line="306"/>
        <source>Imported on </source>
        <translation>vayďê mênê</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="227"/>
        <source>Select</source>
        <translation>pêsand</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="1326"/>
        <source>Unselect</source>
        <translation>pêsand nako</translation>
    </message>
</context>
<context>
    <name>ReName</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ReName.qml" line="66"/>
        <source>Input a new name</source>
        <translation>أدخل اسمًا جديدًا</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ReName.qml" line="81"/>
        <source>The file already exists, please use another name</source>
        <translation>fāyl zê pîštar hêďês, ya nomê di vê kār bêgêr</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ReName.qml" line="137"/>
        <source>Cancel</source>
        <translation>raď kerdên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ReName.qml" line="119"/>
        <source>Confirm</source>
        <translation>qêwul kerdên</translation>
    </message>
</context>
<context>
    <name>RecentlyDeletedView</name>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="52"/>
        <source>1 photo</source>
        <translation>šîvāt 1</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="54"/>
        <source>%1 photos</source>
        <translation>%1 šîvāt</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="62"/>
        <source>1 video</source>
        <translation>1 film</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="64"/>
        <source>%1 videos</source>
        <translation>%1 film</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="120"/>
        <source>Trash</source>
        <translation>dalâšqâli</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="141"/>
        <source>The files will be permanently deleted after the days shown on them</source>
        <translation>fāylā ba'ď zê ruzā nêšow dāďê mênêsow si hamîša pāk ebun</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="156"/>
        <source>Delete All</source>
        <translation>pāk kerdênê poy</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="196"/>
        <source>Delete Selected (%1)</source>
        <translation>pāk kerdênê pêsand vâbiďê (%1)</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/RecentlyDeletedView/RecentlyDeletedView.qml" line="216"/>
        <source>Restore Selected (%1)</source>
        <translation>vorgandênê pêsand vâbiďê (%1)</translation>
    </message>
</context>
<context>
    <name>RemoveAlbumDialog</name>
    <message>
        <location filename="../qml/Control/RemoveAlbumDialog.qml" line="42"/>
        <source>Are you sure you want to delete this album?</source>
        <translation>zê rāsti êxoy î ālbomê pāk koni?</translation>
    </message>
    <message>
        <location filename="../qml/Control/RemoveAlbumDialog.qml" line="55"/>
        <source>Cancel</source>
        <translation>raď kerdên</translation>
    </message>
    <message>
        <location filename="../qml/Control/RemoveAlbumDialog.qml" line="72"/>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
</context>
<context>
    <name>RemoveDialog</name>
    <message>
        <location filename="../qml/PreviewImageViewer/Dialog/RemoveDialog.qml" line="66"/>
        <source>Cannot move "%1" to the trash. Do you want to permanently delete it?</source>
        <translation>لا يمكن نقل "%1" إلى سلة المهملات. هل تريد حذفها بشكل دائم؟</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/Dialog/RemoveDialog.qml" line="84"/>
        <source>This action cannot be undone</source>
        <translation>هذا الإجراء لا يمكن إلغاؤه</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/Dialog/RemoveDialog.qml" line="96"/>
        <source>Cancel</source>
        <translation>raď kerdên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/Dialog/RemoveDialog.qml" line="106"/>
        <source>Confirm</source>
        <translation>qêwul kerdên</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="51"/>
        <source>1 photo found</source>
        <translation>1 šîvāt jurêhest</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="53"/>
        <source>%1 photos found</source>
        <translation>%1 šîvāt jurêhest</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="57"/>
        <source>1 video found</source>
        <translation>1 film jurêhest</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="59"/>
        <source>%1 videos found</source>
        <translation>%1 film jurêhest</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="64"/>
        <source>%1 items found</source>
        <translation>%1 āytêm jurêhest</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="96"/>
        <source>Search results</source>
        <translation>nêtijêhā pitiniďên</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="109"/>
        <source>Slide Show</source>
        <translation>nêšow dāďênê êslāyd</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/SearchView.qml" line="186"/>
        <source>No search results</source>
        <translation>pitiniďên bî nêtijê bi</translation>
    </message>
</context>
<context>
    <name>Sidebar</name>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="127"/>
        <source>Album “%1” removed</source>
        <translation>ālbom “%1” pāk vâbiďê</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="205"/>
        <source>Gallery</source>
        <translation>šîvātmāl</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="208"/>
        <source>Collection</source>
        <translation>vāyakal</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="209"/>
        <source>Import</source>
        <translation>vê mên avordên</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="210"/>
        <source>Favorites</source>
        <translation>xāstênýal</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="211"/>
        <source>Trash</source>
        <translation>dalâšqâli</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="234"/>
        <source>Device</source>
        <translation>dasgā</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="292"/>
        <source>Albums</source>
        <translation>ālbomā</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="313"/>
        <source>Add an album</source>
        <translation>ezaf kerdênê ya ālbom</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="340"/>
        <source>Screen Capture</source>
        <translation>zaftê niyaštgêr</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="344"/>
        <source>Camera</source>
        <translation>šîvātgêr</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="348"/>
        <source>Draw</source>
        <translation>kašiďên</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="455"/>
        <source>Slide show</source>
        <translation>nêšow dāďênê êslāyd</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="466"/>
        <source>Export</source>
        <translation>vêdar kerdên</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="500"/>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="543"/>
        <source>New album</source>
        <translation>ālbom nu</translation>
    </message>
    <message>
        <location filename="../qml/SideBar/Sidebar.qml" line="555"/>
        <source>Rename</source>
        <translation>ālêštê nom</translation>
    </message>
</context>
<context>
    <name>SliderShow</name>
    <message>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="164"/>
        <source>Previous</source>
        <translation>niyâyi</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="181"/>
        <source>Pause</source>
        <translation>vāstāďên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="181"/>
        <source>Play</source>
        <translation>pêšk</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="197"/>
        <source>Next</source>
        <translation>dindâyi</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/SliderShow.qml" line="212"/>
        <source>Exit</source>
        <translation>vêdar zayďên</translation>
    </message>
</context>
<context>
    <name>ThumbnailListDelegate</name>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListDelegate.qml" line="441"/>
        <source>days</source>
        <translation>ruzā</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListDelegate.qml" line="441"/>
        <source>day</source>
        <translation>ruz</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="610"/>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="171"/>
        <source>Back to Album</source>
        <translation>vorgaštên vê ālbom</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="203"/>
        <source>Previous</source>
        <translation>niyâyi</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="228"/>
        <source>Next</source>
        <translation>dindâyi</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="264"/>
        <source>Original size</source>
        <translation>hêndā alsi</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="283"/>
        <source>Fit to window</source>
        <translation>jā dāďên mênê nimdari</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="301"/>
        <source>Rotate</source>
        <translation>dêr xardên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="335"/>
        <source>Favorite</source>
        <translation>xāsta</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="335"/>
        <source>Unfavorite</source>
        <translation>naxāsta</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ThumbnailListView.qml" line="591"/>
        <source>Extract text</source>
        <translation>dêravordênê hîl</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaildelegate.cpp" line="207"/>
        <source>days</source>
        <translation>ruzā</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="699"/>
        <source>Photo info</source>
        <translation>dovêsmandi šîvāt</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="700"/>
        <source>Video info</source>
        <translation>dowêsmandiyā film</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="721"/>
        <source>View</source>
        <translation>niyaštên</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="722"/>
        <source>Fullscreen</source>
        <translation>poy balga</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="723"/>
        <source>Slide show</source>
        <translation>nêšow dāďênê êslāyd</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="724"/>
        <source>Export</source>
        <translation>vêdar kerdên</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="734"/>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="742"/>
        <source>Remove from album</source>
        <translation>pāk kerdên zê ālbom</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="744"/>
        <source>Print</source>
        <translation>čāp</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="754"/>
        <source>Rotate clockwise</source>
        <translation>dêr xardên vê jo'meštê šāxakā sāat </translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="755"/>
        <source>Rotate counterclockwise</source>
        <translation>dêr xardên čavāsê jo'mêštê šāxakā sāat</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="756"/>
        <source>Display in file manager</source>
        <translation>niyaštgêr mênê dîvowdâri fāyl</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="759"/>
        <source>Set as wallpaper</source>
        <translation>sāmov vê onvānê balga zêmîna</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="927"/>
        <source>Restore</source>
        <translation>vorgandên</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="964"/>
        <source>Add to album</source>
        <translation>ezaf kerdên vê ālbom</translation>
    </message>
    <message>
        <location filename="../src/widgets/thumbnail/thumbnaillistview.cpp" line="968"/>
        <source>New album</source>
        <translation>ālbom nu</translation>
    </message>
</context>
<context>
    <name>ThumbnailListViewAlbum</name>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="796"/>
        <source>View</source>
        <translation>niyaštên</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="805"/>
        <source>Fullscreen</source>
        <translation>poy balga</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="822"/>
        <source>Print</source>
        <translation>čāp</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="841"/>
        <source>Slide show</source>
        <translation>nêšow dāďênê êslāyd</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="867"/>
        <source>Add to album</source>
        <translation>ezaf kerdên vê ālbom</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="870"/>
        <source>New album</source>
        <translation>ālbom nu</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="902"/>
        <source>Successfully added to “%1”</source>
        <translation>vê xuwi ezaf vâbi vê “%1”</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="911"/>
        <source>Export</source>
        <translation>vêdar kerdên</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="930"/>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="939"/>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="949"/>
        <source>Remove from album</source>
        <translation>pāk kerdên zê ālbom</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="964"/>
        <source>Favorite</source>
        <translation>xāsta</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="974"/>
        <source>Unfavorite</source>
        <translation>naxāsta</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="988"/>
        <source>Rotate clockwise</source>
        <translation>dêr xardên vê jo'meštê šāxakā sāat </translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="997"/>
        <source>Rotate counterclockwise</source>
        <translation>dêr xardên čavāsê jo'mêštê šāxakā sāat</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="1006"/>
        <source>Set as wallpaper</source>
        <translation>sāmov vê onvānê balga zêmîna</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="1025"/>
        <source>Display in file manager</source>
        <translation>niyaštgêr mênê dîvowdâri fāyl</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="1044"/>
        <source>Restore</source>
        <translation>vorgandên</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="1053"/>
        <source>Photo info</source>
        <translation>dovêsmandi šîvāt</translation>
    </message>
    <message>
        <location filename="../qml/Control/ListView/ThumbnailListViewAlbum.qml" line="1072"/>
        <source>Video info</source>
        <translation>dowêsmandiyā film</translation>
    </message>
</context>
<context>
    <name>TimeLineView</name>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="289"/>
        <source>1 photo</source>
        <translation>1 šîvāt</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="291"/>
        <source>1 video</source>
        <translation>1 film</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="293"/>
        <source>%n photos</source>
        <translation>%n šîvāt%n šîvāt</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="295"/>
        <source>%n videos</source>
        <translation>%n film%n film</translation>
    </message>
    <message>
        <location filename="../src/widgets/timelineview/timelineview.cpp" line="297"/>
        <source>%n items</source>
        <translation>%n āytêm%n āytêm</translation>
    </message>
</context>
<context>
    <name>ToolBarThumbnailListView</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="121"/>
        <source>Back to Album</source>
        <translation>vorgaštên vê ālbom</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="162"/>
        <source>Previous</source>
        <translation>niyâyi</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="189"/>
        <source>Next</source>
        <translation>dindâyi</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="210"/>
        <source>Original size</source>
        <translation>hêndā alsi</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="231"/>
        <source>Fit to window</source>
        <translation>jā dāďên mênê nimdari</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="257"/>
        <source>Rotate</source>
        <translation>dêr xardên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="290"/>
        <source>Favorite</source>
        <translation>xāsta</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="290"/>
        <source>Unfavorite</source>
        <translation>naxāsta</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="431"/>
        <source>Extract text</source>
        <translation>dêravordênê hîl</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ToolBarThumbnailListView.qml" line="458"/>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
</context>
<context>
    <name>VideoInfoDialog</name>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="73"/>
        <source>Basic info</source>
        <translation>dovêsmandi bončak</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="78"/>
        <source>File name</source>
        <translation>nomê fāyl</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="88"/>
        <source>Date captured</source>
        <translation>virgārê zaft vâbiďe</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="95"/>
        <source>Size</source>
        <translation>hêndā</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="100"/>
        <source>Duration</source>
        <translation>zamovê lańgi</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="105"/>
        <source>Type</source>
        <translation>'no </translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="115"/>
        <source>Path</source>
        <translation>ra'</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="122"/>
        <source>Codec info</source>
        <translation>dowêsmandiyā kodêk</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="130"/>
        <source>Video CodecID</source>
        <translation>âydi kodêkê film</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="136"/>
        <source>Video CodeRate</source>
        <translation>nêrxê kodê film</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="142"/>
        <source>FPS</source>
        <translation>fps</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="153"/>
        <source>Proportion</source>
        <translation>kot</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="160"/>
        <source>Resolution</source>
        <translation>diyâri</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="178"/>
        <source>Audio CodecID</source>
        <translation>âydi kodêkê dong</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="184"/>
        <source>Audio CodeRate</source>
        <translation>nêrxê kodê dong</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="190"/>
        <source>Audio digit</source>
        <translation>raqamê dongi</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="201"/>
        <source>Channels</source>
        <translation>torgêyal</translation>
    </message>
    <message>
        <location filename="../qml/Control/VideoInfoDialog.qml" line="208"/>
        <source>Sampling</source>
        <translation>nêmove vordâri</translation>
    </message>
</context>
<context>
    <name>ViewRightMenu</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="40"/>
        <source>Fullscreen</source>
        <translation>poy balga</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="40"/>
        <source>Exit fullscreen</source>
        <translation>vêdar zayďênê poy balga</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="60"/>
        <source>Print</source>
        <translation>čāp</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="81"/>
        <source>Extract text</source>
        <translation>dêravordênê hîl</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="103"/>
        <source>Slide show</source>
        <translation>nêšow dāďênê êslāyd</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="128"/>
        <source>Export</source>
        <translation>vêdar kerdên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="144"/>
        <source>Copy</source>
        <translation>lefgiri</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="168"/>
        <source>Rename</source>
        <translation>ālêštê nom</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="189"/>
        <source>Delete</source>
        <translation>pāk kerdên</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="218"/>
        <source>Favorite</source>
        <translation>xāsta</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="228"/>
        <source>Unfavorite</source>
        <translation>naxāsta</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="245"/>
        <source>Rotate clockwise</source>
        <translation>dêr xardên vê jo'meštê šāxakā sāat </translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="267"/>
        <source>Rotate counterclockwise</source>
        <translation>dêr xardên čavāsê jo'mêštê šāxakā sāat</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="297"/>
        <source>Show navigation window</source>
        <translation>nêšow dāďênê ra'jurê nimdari</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="297"/>
        <source>Hide navigation window</source>
        <translation>bîďār kerdênê ra'jurê nimdari</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="309"/>
        <source>Set as wallpaper</source>
        <translation>sāmov vê onvānê balga zêmîna</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="331"/>
        <source>Display in file manager</source>
        <translation>niyaštgêr mênê dîvowdâri fāyl</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewRightMenu.qml" line="350"/>
        <source>Image info</source>
        <translation>dovêsmandi šîvāt</translation>
    </message>
</context>
<context>
    <name>ViewTopTitle</name>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="162"/>
        <source>Open image</source>
        <translation>فتح الصورة</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="184"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>مُحَوِّر الصور هو أداة لعرض الصور مع واجهة أنيقة ومستوى أداء سلس.</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="185"/>
        <source>Album is a stylish management tool for viewing and organizing photos and videos.</source>
        <translation>ālbom ya awzārê dîvowdâri tis si nýaštên vo sāmow dāďên vê šîvātā vo filmā hêď.</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="188"/>
        <source>Image Viewer</source>
        <translation>مُحَوِّر الصور</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="189"/>
        <source>Album</source>
        <translation>ālbom</translation>
    </message>
    <message>
        <location filename="../qml/PreviewImageViewer/ViewTopTitle.qml" line="193"/>
        <source>%1 is released under %2.</source>
        <translation>%1 تم الإفراج عنه بموجب %2.</translation>
    </message>
</context>
<context>
    <name>YearCollection</name>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/YearCollection.qml" line="126"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/YearCollection.qml" line="139"/>
        <source>%1 items</source>
        <translation>%1 āytêm</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailImageView/CollecttionView/YearCollection.qml" line="139"/>
        <source>1 item</source>
        <translation>1 āytêm</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="130"/>
        <source>All photos and videos</source>
        <translation>poy šîvātā vo filmā</translation>
    </message>
</context>
</TS>
